@@ -282,7 +282,7 @@ def check_nsp(dist, attr, value):
             )
         msg = (
             "The namespace_packages parameter is deprecated, "
-            "consider using implicit namespaces instead (PEP 420).",
+            "consider using implicit namespaces instead (PEP 420)."
         )
         warnings.warn(msg, SetuptoolsDeprecationWarning)
 
